'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var passportGitlab2 = require('passport-gitlab2');
var pluginAuthNode = require('@backstage/plugin-auth-node');
var backendPluginApi = require('@backstage/backend-plugin-api');

const gitlabAuthenticator = pluginAuthNode.createOAuthAuthenticator({
  defaultProfileTransform: pluginAuthNode.PassportOAuthAuthenticatorHelper.defaultProfileTransform,
  scopes: {
    required: ["read_user"]
  },
  initialize({ callbackUrl, config }) {
    const clientId = config.getString("clientId");
    const clientSecret = config.getString("clientSecret");
    const baseUrl = config.getOptionalString("audience") || "https://gitlab.com";
    return pluginAuthNode.PassportOAuthAuthenticatorHelper.from(
      new passportGitlab2.Strategy(
        {
          clientID: clientId,
          clientSecret,
          callbackURL: callbackUrl,
          baseURL: baseUrl,
          authorizationURL: `${baseUrl}/oauth/authorize`,
          tokenURL: `${baseUrl}/oauth/token`,
          profileURL: `${baseUrl}/api/v4/user`
        },
        (accessToken, refreshToken, params, fullProfile, done) => {
          done(
            void 0,
            { fullProfile, params, accessToken },
            { refreshToken }
          );
        }
      )
    );
  },
  async start(input, helper) {
    return helper.start(input, {
      accessType: "offline",
      prompt: "consent"
    });
  },
  async authenticate(input, helper) {
    return helper.authenticate(input);
  },
  async refresh(input, helper) {
    return helper.refresh(input);
  }
});

exports.gitlabSignInResolvers = void 0;
((gitlabSignInResolvers2) => {
  gitlabSignInResolvers2.usernameMatchingUserEntityName = pluginAuthNode.createSignInResolverFactory({
    create() {
      return async (info, ctx) => {
        const { result } = info;
        const id = result.fullProfile.username;
        if (!id) {
          throw new Error(`GitLab user profile does not contain a username`);
        }
        return ctx.signInWithCatalogUser({ entityRef: { name: id } });
      };
    }
  });
})(exports.gitlabSignInResolvers || (exports.gitlabSignInResolvers = {}));

const authModuleGitlabProvider = backendPluginApi.createBackendModule({
  pluginId: "auth",
  moduleId: "gitlab-provider",
  register(reg) {
    reg.registerInit({
      deps: {
        providers: pluginAuthNode.authProvidersExtensionPoint
      },
      async init({ providers }) {
        providers.registerProvider({
          providerId: "gitlab",
          factory: pluginAuthNode.createOAuthProviderFactory({
            authenticator: gitlabAuthenticator,
            signInResolverFactories: {
              ...exports.gitlabSignInResolvers,
              ...pluginAuthNode.commonSignInResolvers
            }
          })
        });
      }
    });
  }
});

exports.default = authModuleGitlabProvider;
exports.gitlabAuthenticator = gitlabAuthenticator;
//# sourceMappingURL=index.cjs.js.map
